diff --git a/bower.json b/bower.json
index 51df028..79367f7 100644
--- a/bower.json
+++ b/bower.json
@@ -1,6 +1,6 @@
 {
   "name": "pagePiling.js",
-  "version": "1.0",
+  "version": "1.2",
   "homepage": "https://github.com/alvarotrigo/pagePiling.js",
   "authors": [
     "Alvaro Trigo https://github.com/alvarotrigo"
diff --git a/jquery.pagepiling.js b/jquery.pagepiling.js
index ea4d1fa..644a67c 100644
--- a/jquery.pagepiling.js
+++ b/jquery.pagepiling.js
@@ -1,5 +1,5 @@
 /* ===========================================================
- * pagepiling.js 1.0
+ * pagepiling.js 1.2
  *
  * https://github.com/alvarotrigo/pagePiling.js
  * MIT licensed
@@ -9,7 +9,7 @@
  * ========================================================== */
 
 (function ($) {
-    $.fn.pagepiling = function (options) {
+    $.fn.pagepiling = function (custom) {
         var container = $(this);
         var lastScrolledDestiny;
         var lastAnimation = 0;
@@ -22,7 +22,7 @@
         var scrollDelay = 600;
 
         // Create some defaults, extending them with any options that were provided
-        options = $.extend({
+        options = $.extend(true, {
             direction: 'vertical',
             menu: null,
             verticalCentered: true,
@@ -34,10 +34,10 @@
             loopTop: false,
             css3: true,
             navigation: {
-                'textColor': '#000',
-                'bulletsColor': '#000',
-                'position': 'right',
-                'tooltips': ['section1', 'section2', 'section3', 'section4']
+                textColor: '#000',
+                bulletsColor: '#000',
+                position: 'right',
+                tooltips: null
             },
             normalScrollElements: null,
             normalScrollElementTouchThreshold: 5,
@@ -50,7 +50,7 @@
             afterLoad: null,
             onLeave: null,
             afterRender: null
-        }, options);
+        }, custom);
 
 
         //easeInQuart animation included in the plugin
@@ -709,15 +709,26 @@
             return events;
         }
 
+        /**
+        * As IE >= 10 fires both touch and mouse events when using a mouse in a touchscreen
+        * this way we make sure that is really a touch event what IE is detecting.
+        */
+        function isReallyTouch(e){
+            //if is not IE   ||  IE is detecting `touch` or `pen`
+            return typeof e.pointerType === 'undefined' || e.pointerType != 'mouse';
+        }
+
         /**
         * Getting the starting possitions of the touch event
         */
         function touchStartHandler(event){
-
             var e = event.originalEvent;
-            var touchEvents = getEventsPage(e);
-            touchStartY = touchEvents['y'];
-            touchStartX = touchEvents['x'];
+
+            if(isReallyTouch(e)){
+                var touchEvents = getEventsPage(e);
+                touchStartY = touchEvents['y'];
+                touchStartX = touchEvents['x'];
+            }
         }
 
         /* Detecting touch events
@@ -726,7 +737,7 @@
             var e = event.originalEvent;
 
             // additional: if one of the normalScrollElements isn't within options.normalScrollElementTouchThreshold hops up the DOM chain
-            if (!checkParentForNormalScrollElement(event.target)) {
+            if ( !checkParentForNormalScrollElement(event.target) && isReallyTouch(e) ) {
                 event.preventDefault();
 
                 var activeSection = $('.pp-section.active');
diff --git a/jquery.pagepiling.min.js b/jquery.pagepiling.min.js
index 8a7070a..7a472c9 100644
--- a/jquery.pagepiling.min.js
+++ b/jquery.pagepiling.min.js
@@ -1,5 +1,5 @@
 /* ===========================================================
- * pagepiling.js 1.0
+ * pagepiling.js 1.2
  *
  * https://github.com/alvarotrigo/pagePiling.js
  * MIT licensed
@@ -8,22 +8,23 @@
  *
  * ========================================================== */
 
-(function(b){b.fn.pagepiling=function(c){function B(a){var f=b(".pp-section.active").index(".pp-section");a=a.index(".pp-section");return f>a?"up":"down"}function g(a,f){var d={destination:a,animated:f,activeSection:b(".pp-section.active"),anchorLink:a.data("anchor"),sectionIndex:a.index(".pp-section"),toMove:a,yMovement:B(a),leavingSection:b(".pp-section.active").index(".pp-section")+1};d.activeSection.is(a)||("undefined"===typeof d.animated&&(d.animated=!0),"undefined"!==typeof d.anchorLink&&C(d.anchorLink,
-d.sectionIndex),d.destination.addClass("active").siblings().removeClass("active"),d.sectionsToMove=D(d),"down"===d.yMovement?(d.translate3d="vertical"!==c.direction?"translate3d(-100%, 0px, 0px)":"translate3d(0px, -100%, 0px)",d.scrolling="-100%",c.css3||d.sectionsToMove.each(function(a){a!=d.activeSection.index(".pp-section")&&b(this).css(m(d.scrolling))}),d.animateSection=d.activeSection):(d.translate3d="translate3d(0px, 0px, 0px)",d.scrolling="0",d.animateSection=a),b.isFunction(c.onLeave)&&c.onLeave.call(this,
-d.leavingSection,d.sectionIndex+1,d.yMovement),E(d),F(d.anchorLink),G(d.anchorLink,d.sectionIndex),r=d.anchorLink,s=(new Date).getTime())}function E(a){c.css3?(t(a.animateSection,a.translate3d,a.animated),a.sectionsToMove.each(function(){t(b(this),a.translate3d,a.animated)}),setTimeout(function(){n(a)},c.scrollingSpeed)):(a.scrollOptions=m(a.scrolling),a.animated?a.animateSection.animate(a.scrollOptions,c.scrollingSpeed,c.easing,function(){u(a);n(a)}):(a.animateSection.css(m(a.scrolling)),setTimeout(function(){u(a);
-n(a)},400)))}function n(a){b.isFunction(c.afterLoad)&&c.afterLoad.call(this,a.anchorLink,a.sectionIndex+1)}function D(a){return"down"===a.yMovement?b(".pp-section").map(function(f){if(f<a.destination.index(".pp-section"))return b(this)}):b(".pp-section").map(function(f){if(f>a.destination.index(".pp-section"))return b(this)})}function u(a){"up"===a.yMovement&&a.sectionsToMove.each(function(f){b(this).css(m(a.scrolling))})}function m(a){return"vertical"===c.direction?{top:a}:{left:a}}function C(a,
-b){c.anchors.length?(location.hash=a,v(location.hash)):v(String(b))}function v(a){a=a.replace("#","");b("body")[0].className=b("body")[0].className.replace(/\b\s?pp-viewing-[^\s]+\b/g,"");b("body").addClass("pp-viewing-"+a)}function p(){return(new Date).getTime()-s<600+c.scrollingSpeed?!0:!1}function t(a,b,c){a.toggleClass("pp-easing",c);a.css({"-webkit-transform":b,"-moz-transform":b,"-ms-transform":b,transform:b})}function h(a){if(!p()){a=window.event||a;a=Math.max(-1,Math.min(1,a.wheelDelta||-a.deltaY||
--a.detail));var c=b(".pp-section.active"),c=w(c);0>a?k("down",c):k("up",c);return!1}}function k(a,c){if("down"==a)var d="bottom",e=b.fn.pagepiling.moveSectionDown;else d="top",e=b.fn.pagepiling.moveSectionUp;if(0<c.length)if(isScrolled(d,c))e();else return!0;else e()}function w(a){return scrollable=a.find(".pp-scrollable")}function x(){return window.PointerEvent?{down:"pointerdown",move:"pointermove",up:"pointerup"}:{down:"MSPointerDown",move:"MSPointerMove",up:"MSPointerUp"}}function y(a){var b=
-[];b.y="undefined"!==typeof a.pageY&&(a.pageY||a.pageX)?a.pageY:a.touches[0].pageY;b.x="undefined"!==typeof a.pageX&&(a.pageY||a.pageX)?a.pageX:a.touches[0].pageX;return b}function H(a){a=y(a.originalEvent);l=a.y;touchStartX=a.x}function I(a){var f=a.originalEvent;z(a.target)||(a.preventDefault(),a=b(".pp-section.active"),a=w(a),p()||(f=y(f),touchEndY=f.y,touchEndX=f.x,"horizontal"===c.direction&&Math.abs(touchStartX-touchEndX)>Math.abs(l-touchEndY)?Math.abs(touchStartX-touchEndX)>e.width()/100*c.touchSensitivity&&
-(touchStartX>touchEndX?k("down",a):touchEndX>touchStartX&&k("up",a)):Math.abs(l-touchEndY)>e.height()/100*c.touchSensitivity&&(l>touchEndY?k("down",a):touchEndY>l&&k("up",a))))}function z(a,f){f=f||0;var d=b(a).parent();return f<c.normalScrollElementTouchThreshold&&d.is(c.normalScrollElements)?!0:f==c.normalScrollElementTouchThreshold?!1:z(d,++f)}function J(){b("body").append('<div id="pp-nav"><ul></ul></div>');var a=b("#pp-nav");a.css("color",c.navigation.textColor);a.addClass(c.navigation.position);
-for(var f=0;f<b(".pp-section").length;f++){var d="";c.anchors.length&&(d=c.anchors[f]);if("undefined"!==typeof c.navigation.tooltips){var e=c.navigation.tooltips[f];"undefined"===typeof e&&(e="")}a.find("ul").append('<li data-tooltip="'+e+'"><a href="#'+d+'"><span></span></a></li>')}a.find("span").css("border-color",c.navigation.bulletsColor)}function G(a,f){c.navigation&&(b("#pp-nav").find(".active").removeClass("active"),a?b("#pp-nav").find('a[href="#'+a+'"]').addClass("active"):b("#pp-nav").find("li").eq(f).find("a").addClass("active"))}
-function F(a){c.menu&&(b(c.menu).find(".active").removeClass("active"),b(c.menu).find('[data-menuanchor="'+a+'"]').addClass("active"))}function K(){var a=document.createElement("p"),b,c={webkitTransform:"-webkit-transform",OTransform:"-o-transform",msTransform:"-ms-transform",MozTransform:"-moz-transform",transform:"transform"};document.body.insertBefore(a,null);for(var e in c)void 0!==a.style[e]&&(a.style[e]="translate3d(1px,1px,1px)",b=window.getComputedStyle(a).getPropertyValue(c[e]));document.body.removeChild(a);
-return void 0!==b&&0<b.length&&"none"!==b}var e=b(this),r,s=0,A="ontouchstart"in window||0<navigator.msMaxTouchPoints||navigator.maxTouchPoints,l=touchStartX=touchEndY=touchEndX=0;c=b.extend({direction:"vertical",menu:null,verticalCentered:!0,sectionsColor:[],anchors:[],scrollingSpeed:700,easing:"easeInQuart",loopBottom:!1,loopTop:!1,css3:!0,navigation:{textColor:"#000",bulletsColor:"#000",position:"right",tooltips:["section1","section2","section3","section4"]},normalScrollElements:null,normalScrollElementTouchThreshold:5,
-touchSensitivity:5,keyboardScrolling:!0,sectionSelector:".section",animateAnchor:!1,afterLoad:null,onLeave:null,afterRender:null},c);b.extend(b.easing,{easeInQuart:function(a,b,c,e,g){return e*(b/=g)*b*b*b+c}});b.fn.pagepiling.setScrollingSpeed=function(a){c.scrollingSpeed=a};b.fn.pagepiling.setMouseWheelScrolling=function(a){a?e.get(0).addEventListener?(e.get(0).addEventListener("mousewheel",h,!1),e.get(0).addEventListener("wheel",h,!1)):e.get(0).attachEvent("onmousewheel",h):e.get(0).addEventListener?
-(e.get(0).removeEventListener("mousewheel",h,!1),e.get(0).removeEventListener("wheel",h,!1)):e.get(0).detachEvent("onmousewheel",h)};b.fn.pagepiling.setAllowScrolling=function(a){a?(b.fn.pagepiling.setMouseWheelScrolling(!0),A&&(MSPointer=x(),e.off("touchstart "+MSPointer.down).on("touchstart "+MSPointer.down,H),e.off("touchmove "+MSPointer.move).on("touchmove "+MSPointer.move,I))):(b.fn.pagepiling.setMouseWheelScrolling(!1),A&&(MSPointer=x(),e.off("touchstart "+MSPointer.down),e.off("touchmove "+
-MSPointer.move)))};b.fn.pagepiling.setKeyboardScrolling=function(a){c.keyboardScrolling=a};b.fn.pagepiling.moveSectionUp=function(){var a=b(".pp-section.active").prev(".pp-section");!a.length&&c.loopTop&&(a=b(".pp-section").last());a.length&&g(a)};b.fn.pagepiling.moveSectionDown=function(){var a=b(".pp-section.active").next(".pp-section");!a.length&&c.loopBottom&&(a=b(".pp-section").first());a.length&&g(a)};b.fn.pagepiling.moveTo=function(a){var c="",c=isNaN(a)?b('[data-anchor="'+a+'"]'):b(".pp-section").eq(a-
-1);0<c.length&&g(c)};b(c.sectionSelector).each(function(){b(this).addClass("pp-section")});c.css3&&(c.css3=K());b(e).css({overflow:"hidden","-ms-touch-action":"none","touch-action":"none"});b.fn.pagepiling.setAllowScrolling(!0);b.isEmptyObject(c.navigation)||J();var q=b(".pp-section").length;b(".pp-section").each(function(a){b(this).data("data-index",a);b(this).css("z-index",q);a||0!==b(".pp-section.active").length||b(this).addClass("active");"undefined"!==typeof c.anchors[a]&&b(this).attr("data-anchor",
-c.anchors[a]);"undefined"!==typeof c.sectionsColor[a]&&b(this).css("background-color",c.sectionsColor[a]);c.verticalCentered&&b(this).addClass("pp-table").wrapInner('<div class="pp-tableCell" style="height:100%" />');--q}).promise().done(function(){c.navigation&&(b("#pp-nav").css("margin-top","-"+b("#pp-nav").height()/2+"px"),b("#pp-nav").find("li").eq(b(".pp-section.active").index(".pp-section")).find("a").addClass("active"));b(window).on("load",function(){var a=window.location.hash.replace("#",
-""),a=b('.pp-section[data-anchor="'+a+'"]');0<a.length&&g(a,c.animateAnchor)});b.isFunction(c.afterRender)&&c.afterRender.call(this)});b(window).on("hashchange",function(){var a=window.location.hash.replace("#","").split("/")[0];a.length&&a&&a!==r&&(a=isNaN(a)?b('[data-anchor="'+a+'"]'):b(".pp-section").eq(a-1),g(a))});b(document).keydown(function(a){if(c.keyboardScrolling&&!p())switch(a.which){case 38:case 33:b.fn.pagepiling.moveSectionUp();break;case 40:case 34:b.fn.pagepiling.moveSectionDown();
-break;case 36:b.fn.pagepiling.moveTo(1);break;case 35:b.fn.pagepiling.moveTo(b(".pp-section").length);break;case 37:b.fn.pagepiling.moveSectionUp();break;case 39:b.fn.pagepiling.moveSectionDown()}});c.normalScrollElements&&(b(document).on("mouseenter",c.normalScrollElements,function(){b.fn.pagepiling.setMouseWheelScrolling(!1)}),b(document).on("mouseleave",c.normalScrollElements,function(){b.fn.pagepiling.setMouseWheelScrolling(!0)}));b(document).on("click touchstart","#pp-nav a",function(a){a.preventDefault();
-a=b(this).parent().index();g(b(".pp-section").eq(a))});b(document).on({mouseenter:function(){var a=b(this).data("tooltip");b('<div class="pp-tooltip '+c.navigation.position+'">'+a+"</div>").hide().appendTo(b(this)).fadeIn(200)},mouseleave:function(){b(this).find(".pp-tooltip").fadeOut(200,function(){b(this).remove()})}},"#pp-nav li")}})(jQuery);
\ No newline at end of file
+(function(b){b.fn.pagepiling=function(C){function D(a){var d=b(".pp-section.active").index(".pp-section");a=a.index(".pp-section");return d>a?"up":"down"}function f(a,d){var c={destination:a,animated:d,activeSection:b(".pp-section.active"),anchorLink:a.data("anchor"),sectionIndex:a.index(".pp-section"),toMove:a,yMovement:D(a),leavingSection:b(".pp-section.active").index(".pp-section")+1};c.activeSection.is(a)||("undefined"===typeof c.animated&&(c.animated=!0),"undefined"!==typeof c.anchorLink&&E(c.anchorLink,
+c.sectionIndex),c.destination.addClass("active").siblings().removeClass("active"),c.sectionsToMove=F(c),"down"===c.yMovement?(c.translate3d="vertical"!==options.direction?"translate3d(-100%, 0px, 0px)":"translate3d(0px, -100%, 0px)",c.scrolling="-100%",options.css3||c.sectionsToMove.each(function(a){a!=c.activeSection.index(".pp-section")&&b(this).css(l(c.scrolling))}),c.animateSection=c.activeSection):(c.translate3d="translate3d(0px, 0px, 0px)",c.scrolling="0",c.animateSection=a),b.isFunction(options.onLeave)&&
+options.onLeave.call(this,c.leavingSection,c.sectionIndex+1,c.yMovement),G(c),H(c.anchorLink),I(c.anchorLink,c.sectionIndex),q=c.anchorLink,r=(new Date).getTime())}function G(a){options.css3?(t(a.animateSection,a.translate3d,a.animated),a.sectionsToMove.each(function(){t(b(this),a.translate3d,a.animated)}),setTimeout(function(){m(a)},options.scrollingSpeed)):(a.scrollOptions=l(a.scrolling),a.animated?a.animateSection.animate(a.scrollOptions,options.scrollingSpeed,options.easing,function(){u(a);m(a)}):
+(a.animateSection.css(l(a.scrolling)),setTimeout(function(){u(a);m(a)},400)))}function m(a){b.isFunction(options.afterLoad)&&options.afterLoad.call(this,a.anchorLink,a.sectionIndex+1)}function F(a){return"down"===a.yMovement?b(".pp-section").map(function(d){if(d<a.destination.index(".pp-section"))return b(this)}):b(".pp-section").map(function(d){if(d>a.destination.index(".pp-section"))return b(this)})}function u(a){"up"===a.yMovement&&a.sectionsToMove.each(function(d){b(this).css(l(a.scrolling))})}
+function l(a){return"vertical"===options.direction?{top:a}:{left:a}}function E(a,b){options.anchors.length?(location.hash=a,v(location.hash)):v(String(b))}function v(a){a=a.replace("#","");b("body")[0].className=b("body")[0].className.replace(/\b\s?pp-viewing-[^\s]+\b/g,"");b("body").addClass("pp-viewing-"+a)}function n(){return(new Date).getTime()-r<600+options.scrollingSpeed?!0:!1}function t(a,b,c){a.toggleClass("pp-easing",c);a.css({"-webkit-transform":b,"-moz-transform":b,"-ms-transform":b,transform:b})}
+function g(a){if(!n()){a=window.event||a;a=Math.max(-1,Math.min(1,a.wheelDelta||-a.deltaY||-a.detail));var d=b(".pp-section.active"),d=w(d);0>a?h("down",d):h("up",d);return!1}}function h(a,d){if("down"==a)var c="bottom",e=b.fn.pagepiling.moveSectionDown;else c="top",e=b.fn.pagepiling.moveSectionUp;if(0<d.length)if(isScrolled(c,d))e();else return!0;else e()}function w(a){return scrollable=a.find(".pp-scrollable")}function x(){return window.PointerEvent?{down:"pointerdown",move:"pointermove",up:"pointerup"}:
+{down:"MSPointerDown",move:"MSPointerMove",up:"MSPointerUp"}}function y(a){var b=[];b.y="undefined"!==typeof a.pageY&&(a.pageY||a.pageX)?a.pageY:a.touches[0].pageY;b.x="undefined"!==typeof a.pageX&&(a.pageY||a.pageX)?a.pageX:a.touches[0].pageX;return b}function z(a){return"undefined"===typeof a.pointerType||"mouse"!=a.pointerType}function J(a){a=a.originalEvent;z(a)&&(a=y(a),k=a.y,touchStartX=a.x)}function K(a){var d=a.originalEvent;!A(a.target)&&z(d)&&(a.preventDefault(),a=b(".pp-section.active"),
+a=w(a),n()||(d=y(d),touchEndY=d.y,touchEndX=d.x,"horizontal"===options.direction&&Math.abs(touchStartX-touchEndX)>Math.abs(k-touchEndY)?Math.abs(touchStartX-touchEndX)>e.width()/100*options.touchSensitivity&&(touchStartX>touchEndX?h("down",a):touchEndX>touchStartX&&h("up",a)):Math.abs(k-touchEndY)>e.height()/100*options.touchSensitivity&&(k>touchEndY?h("down",a):touchEndY>k&&h("up",a))))}function A(a,d){d=d||0;var c=b(a).parent();return d<options.normalScrollElementTouchThreshold&&c.is(options.normalScrollElements)?
+!0:d==options.normalScrollElementTouchThreshold?!1:A(c,++d)}function L(){b("body").append('<div id="pp-nav"><ul></ul></div>');var a=b("#pp-nav");a.css("color",options.navigation.textColor);a.addClass(options.navigation.position);for(var d=0;d<b(".pp-section").length;d++){var c="";options.anchors.length&&(c=options.anchors[d]);if("undefined"!==typeof options.navigation.tooltips){var e=options.navigation.tooltips[d];"undefined"===typeof e&&(e="")}a.find("ul").append('<li data-tooltip="'+e+'"><a href="#'+
+c+'"><span></span></a></li>')}a.find("span").css("border-color",options.navigation.bulletsColor)}function I(a,d){options.navigation&&(b("#pp-nav").find(".active").removeClass("active"),a?b("#pp-nav").find('a[href="#'+a+'"]').addClass("active"):b("#pp-nav").find("li").eq(d).find("a").addClass("active"))}function H(a){options.menu&&(b(options.menu).find(".active").removeClass("active"),b(options.menu).find('[data-menuanchor="'+a+'"]').addClass("active"))}function M(){var a=document.createElement("p"),
+b,c={webkitTransform:"-webkit-transform",OTransform:"-o-transform",msTransform:"-ms-transform",MozTransform:"-moz-transform",transform:"transform"};document.body.insertBefore(a,null);for(var e in c)void 0!==a.style[e]&&(a.style[e]="translate3d(1px,1px,1px)",b=window.getComputedStyle(a).getPropertyValue(c[e]));document.body.removeChild(a);return void 0!==b&&0<b.length&&"none"!==b}var e=b(this),q,r=0,B="ontouchstart"in window||0<navigator.msMaxTouchPoints||navigator.maxTouchPoints,k=touchStartX=touchEndY=
+touchEndX=0;options=b.extend(!0,{direction:"vertical",menu:null,verticalCentered:!0,sectionsColor:[],anchors:[],scrollingSpeed:700,easing:"easeInQuart",loopBottom:!1,loopTop:!1,css3:!0,navigation:{textColor:"#000",bulletsColor:"#000",position:"right",tooltips:null},normalScrollElements:null,normalScrollElementTouchThreshold:5,touchSensitivity:5,keyboardScrolling:!0,sectionSelector:".section",animateAnchor:!1,afterLoad:null,onLeave:null,afterRender:null},C);b.extend(b.easing,{easeInQuart:function(a,
+b,c,e,f){return e*(b/=f)*b*b*b+c}});b.fn.pagepiling.setScrollingSpeed=function(a){options.scrollingSpeed=a};b.fn.pagepiling.setMouseWheelScrolling=function(a){a?e.get(0).addEventListener?(e.get(0).addEventListener("mousewheel",g,!1),e.get(0).addEventListener("wheel",g,!1)):e.get(0).attachEvent("onmousewheel",g):e.get(0).addEventListener?(e.get(0).removeEventListener("mousewheel",g,!1),e.get(0).removeEventListener("wheel",g,!1)):e.get(0).detachEvent("onmousewheel",g)};b.fn.pagepiling.setAllowScrolling=
+function(a){a?(b.fn.pagepiling.setMouseWheelScrolling(!0),B&&(MSPointer=x(),e.off("touchstart "+MSPointer.down).on("touchstart "+MSPointer.down,J),e.off("touchmove "+MSPointer.move).on("touchmove "+MSPointer.move,K))):(b.fn.pagepiling.setMouseWheelScrolling(!1),B&&(MSPointer=x(),e.off("touchstart "+MSPointer.down),e.off("touchmove "+MSPointer.move)))};b.fn.pagepiling.setKeyboardScrolling=function(a){options.keyboardScrolling=a};b.fn.pagepiling.moveSectionUp=function(){var a=b(".pp-section.active").prev(".pp-section");
+!a.length&&options.loopTop&&(a=b(".pp-section").last());a.length&&f(a)};b.fn.pagepiling.moveSectionDown=function(){var a=b(".pp-section.active").next(".pp-section");!a.length&&options.loopBottom&&(a=b(".pp-section").first());a.length&&f(a)};b.fn.pagepiling.moveTo=function(a){var d="",d=isNaN(a)?b('[data-anchor="'+a+'"]'):b(".pp-section").eq(a-1);0<d.length&&f(d)};b(options.sectionSelector).each(function(){b(this).addClass("pp-section")});options.css3&&(options.css3=M());b(e).css({overflow:"hidden",
+"-ms-touch-action":"none","touch-action":"none"});b.fn.pagepiling.setAllowScrolling(!0);b.isEmptyObject(options.navigation)||L();var p=b(".pp-section").length;b(".pp-section").each(function(a){b(this).data("data-index",a);b(this).css("z-index",p);a||0!==b(".pp-section.active").length||b(this).addClass("active");"undefined"!==typeof options.anchors[a]&&b(this).attr("data-anchor",options.anchors[a]);"undefined"!==typeof options.sectionsColor[a]&&b(this).css("background-color",options.sectionsColor[a]);
+options.verticalCentered&&b(this).addClass("pp-table").wrapInner('<div class="pp-tableCell" style="height:100%" />');--p}).promise().done(function(){options.navigation&&(b("#pp-nav").css("margin-top","-"+b("#pp-nav").height()/2+"px"),b("#pp-nav").find("li").eq(b(".pp-section.active").index(".pp-section")).find("a").addClass("active"));b(window).on("load",function(){var a=window.location.hash.replace("#",""),a=b('.pp-section[data-anchor="'+a+'"]');0<a.length&&f(a,options.animateAnchor)});b.isFunction(options.afterRender)&&
+options.afterRender.call(this)});b(window).on("hashchange",function(){var a=window.location.hash.replace("#","").split("/")[0];a.length&&a&&a!==q&&(a=isNaN(a)?b('[data-anchor="'+a+'"]'):b(".pp-section").eq(a-1),f(a))});b(document).keydown(function(a){if(options.keyboardScrolling&&!n())switch(a.which){case 38:case 33:b.fn.pagepiling.moveSectionUp();break;case 40:case 34:b.fn.pagepiling.moveSectionDown();break;case 36:b.fn.pagepiling.moveTo(1);break;case 35:b.fn.pagepiling.moveTo(b(".pp-section").length);
+break;case 37:b.fn.pagepiling.moveSectionUp();break;case 39:b.fn.pagepiling.moveSectionDown()}});options.normalScrollElements&&(b(document).on("mouseenter",options.normalScrollElements,function(){b.fn.pagepiling.setMouseWheelScrolling(!1)}),b(document).on("mouseleave",options.normalScrollElements,function(){b.fn.pagepiling.setMouseWheelScrolling(!0)}));b(document).on("click touchstart","#pp-nav a",function(a){a.preventDefault();a=b(this).parent().index();f(b(".pp-section").eq(a))});b(document).on({mouseenter:function(){var a=
+b(this).data("tooltip");b('<div class="pp-tooltip '+options.navigation.position+'">'+a+"</div>").hide().appendTo(b(this)).fadeIn(200)},mouseleave:function(){b(this).find(".pp-tooltip").fadeOut(200,function(){b(this).remove()})}},"#pp-nav li")}})(jQuery);
\ No newline at end of file
